@@ -1,9 +1,9 @@
-# environ --- conducts environ analysis 
-# INPUT = network object
-# OUTPUT = input and/or output environs
-# 
-# M. Lau July 2011 | DEH edited Feb 2013
-# ---------------------------------------------------
+#' environ --- conducts environ analysis 
+#' INPUT = network object
+#' OUTPUT = input and/or output environs
+#' 
+#' M. Lau July 2011 | DEH edited Feb 2013
+#' ---------------------------------------------------
 
 enaEnviron <- function(x,input=TRUE,output=TRUE,type='unit',err.tol=1e-10,balance.override=FALSE){
                                         #check for network class
@@ -18,46 +18,46 @@ enaEnviron <- function(x,input=TRUE,output=TRUE,type='unit',err.tol=1e-10,balanc
                                         #calculate enaFlow with RC input
   user.orient <- get.orient()
   set.orient('rc')
-  F <- enaFlow(x)
+  Flow <- enaFlow(x)
   set.orient(user.orient)
                                         #Transpose for calculations in Patten school
-  F$G <- t(F$G)
-  F$GP <- t(F$GP)
-  F$N <- t(F$N)
-  F$NP <- t(F$NP)
+  Flow$G <- t(Flow$G)
+  Flow$GP <- t(Flow$GP)
+  Flow$N <- t(Flow$N)
+  Flow$NP <- t(Flow$NP)
                                         #Unit environ calculations
-  if (input == TRUE){
+  if (input){
                                         #Input perspective
     EP <- list()
-    for (i in (1:nrow(F$NP))){
-      dNP <- diag(F$NP[i,]) #diagonalized N matrix
-      EP[[i]] <- dNP %*% F$GP         # calculate internal environ flows
+    for (i in (1:nrow(Flow$NP))){
+      dNP <- diag(Flow$NP[i,]) #diagonalized N matrix
+      EP[[i]] <- dNP %*% Flow$GP         # calculate internal environ flows
       EP[[i]] <- EP[[i]] - dNP      # place negative environ throughflows on the principle diagonal
       EP[[i]] <- cbind(EP[[i]],apply((-EP[[i]]),1,sum)) #attach z column
       EP[[i]] <- rbind(EP[[i]],c(apply((-EP[[i]]),2,sum))) #attach y row
       EP[[i]][nrow(EP[[i]]),ncol(EP[[i]])] <- 0 #add zero to bottom right corner to complete matrix
       EP[[i]][abs(EP[[i]]) < err.tol] <- 0 #ignore numerical error
                                         #add labels to matrices
-      labels <- c(rownames(F$GP))
+      labels <- c(rownames(Flow$GP))
       colnames(EP[[i]]) = c(labels, 'z')
       rownames(EP[[i]]) = c(labels, 'y')
     }
                                         #add environ names
     names(EP) <- labels
   }
-  if (output == TRUE){
+  if (output){
                                         #Output perspective
     E <- list()
-    for (i in (1:nrow(F$N))){
-      dN <- diag(F$N[,i]) #diagonalized N matrix
-      E[[i]] <- F$G %*% dN
+    for (i in (1:nrow(Flow$N))){
+      dN <- diag(Flow$N[,i]) #diagonalized N matrix
+      E[[i]] <- Flow$G %*% dN
       E[[i]] <- E[[i]] - dN
       E[[i]] <- cbind(E[[i]], apply((-E[[i]]), 1, sum))
       E[[i]] <- rbind(E[[i]], c(apply((-E[[i]]), 2, sum)))
       E[[i]][nrow(E[[i]]), ncol(E[[i]])] <- 0 
       E[[i]][abs(E[[i]]) < err.tol] <- 0 
                                         #add labels to matrices
-      labels <- c(rownames(F$G))
+      labels <- c(rownames(Flow$G))
       colnames(E[[i]]) = c(labels, 'z')
       rownames(E[[i]]) = c(labels, 'y')
     }
@@ -67,24 +67,24 @@ enaEnviron <- function(x,input=TRUE,output=TRUE,type='unit',err.tol=1e-10,balanc
                                         #Realized environ calculations
   if (type == 'realized'){
                                         #Input perspective
-    if (input == TRUE){
-      for (i in (1:nrow(F$N))){
+    if (input){
+      for (i in (1:nrow(Flow$N))){
         EP[[i]] <- EP[[i]]*unpack(x)$y[i] #Construct realized environ
       }
     }
                                         #Output perspective
-    if (output == TRUE){
-      for (i in (1:nrow(F$N))){
+    if (output){
+      for (i in (1:nrow(Flow$N))){
         E[[i]] <- E[[i]]*unpack(x)$z[i]
       }
     }
   }
                                         #Wrap-up output into list  
-  if (input == TRUE & output == TRUE){
+  if (input & output){
     out <- list('input' = EP,'output' = E)
-  } else if (input == TRUE & output == FALSE){
+  } else if (input & output == FALSE){
     out <- EP
-  } else if (input == FALSE & output == TRUE){
+  } else if (input == FALSE & output){
     out <- E
   }      
   
