@@ -1,16 +1,16 @@
-# enaStructure --- performes strucutral analysis of the 
-# network graph (see Borrett et al. 2007)
-# INPUT = network object
-# OUTPUT = list of structure statistics
-# 
-# S. Borrett and M. Lau | March 2011
-# ---------------------------------------------------
+#' enaStructure --- performes strucutral analysis of the
+#' network graph (see Borrett et al. 2007)
+#' INPUT = network object
+#' OUTPUT = list of structure statistics
+#'
+#' S. Borrett and M. Lau | March 2011
+#' ---------------------------------------------------
 
 enaStructure <- function(x = 'network object'){
                                         #Check for network class
   if (class(x) != 'network'){warning('x is not a network class object')}
-  F <- t(x%n%'flow') #get flows
-  A <- sign(F)   # get adjacency matrix
+  Flow <- t(as.matrix(x,attrname = 'flow')) #get flows
+  A <- sign(Flow)   # get adjacency matrix
   sp <- structure.statistics(A)    # calls structure.statistics helper function
                                           #Output orientation
   orient <- get.orient()
